@@ -1038,3 +1038,30 @@ def test_mahalanobis_dist_to_img_filter(tmp_path):
         input_img, output_img, 5, "KEA", rsgislib.TYPE_32FLOAT
     )
     assert os.path.exists(output_img)
+
+
+def test_calc_split_win_thresholds_otsu(tmp_path):
+    import rsgislib.imagecalc
+
+    input_img = os.path.join(IMGCALC_DATA_DIR, "sen2_20210527_aber_ndvi.kea")
+
+    thres_vals = rsgislib.imagecalc.calc_split_win_thresholds(
+        input_img,
+        win_size=500,
+        thres_meth=rsgislib.THRES_METH_OTSU,
+        output_file=None,
+        no_data_val=0.0,
+        lower_valid=None,
+        upper_valid=None,
+        min_n_vals=100,
+        # thres_kwrds = None,
+    )
+
+    n_thres = len(thres_vals[1])
+    assert (
+        (n_thres == 4)
+        and ((thres_vals[1][0] - 0.335) < 0.01)
+        and ((thres_vals[1][1] - 0.692) < 0.01)
+        and ((thres_vals[1][2] - 0.461) < 0.01)
+        and ((thres_vals[1][3] - 0.708) < 0.01)
+    )
